Change Log
**********

..
   All enhancements and patches to help_tokens will be documented
   in this file.  It adheres to the structure of http://keepachangelog.com/ ,
   but in reStructuredText instead of Markdown (for ease of incorporation into
   Sphinx documentation and the PyPI description).

   This project adheres to Semantic Versioning (http://semver.org/).

.. There should always be an "Unreleased" section for changes pending release.

[4.0.0] - 2026-03-26
====================
* Dropped support for Python 3.11.

[3.2.0] - 2025-04-21
====================
* Added support for Python 3.12

[3.1.0] - 2025-04-09
====================
* Dropped support for Python 3.8 and 3.9
* Added support fort Django 5.2

[3.0.0] - 2025-03-14
====================

* Dropped support for edx.readthedocs.io URLs in
  favor of docs.openedx.org URLs.

  See https://github.com/openedx/edx-documentation/issues/2319


[2.4.0] - 2024-03-29
====================

* Added support for Python 3.11
* Dropped support for Django 3.2, Django 4.0 and Django 4.1

[2.3.0] - 2023-08-02
====================

* Added support for Django 4.2

[2.2.0] - 2022-01-20
====================

* Dropped support for django2.2, 3.0, 3.1 and 3.2
* Added Django40 support in CI

[2.1.0] - 2020-07-07
====================

* Added support for django3.0, 3.1 and 3.2

[2.0.0] - 2020-01-19
====================

* Removed support of python3.5

[1.1.0] - 2020-05-05
====================

* Removed support of Django < 2.2 version
* Added support for python 3.8

[1.0.3] - 2017-07-17
====================

* Updated tests to support Django 1.11
* Updated dependency versions


[1.0.2] - 2017-05-16
====================

* Fixed the README.


[1.0.1] - 2017-05-15
====================

* First version on PyPI.


[1.0.0] - 2017-05-03
====================

* First release.
